
/*
 GSG     Part 1: Analysis in native and MNI space - FMR-STC and VMR-VTC projects
 Script for BrainVoyager
 By Joost Mulders, 06-2013
 Modified for BrainVoyager 20.4 by HB, 14-12-16
 - changed 'BrainVoyagerQX' to 'BrainVoyager'
 - changed hardcoding of path to use of BrowseDirectory()
 - added file separator to path and filename concatenation
 - removed references to the file CG2_3DT1FL_CLEAN.vmr (not used in GSG 2.13 any more)
 - added step 22
 Modified for BrainVoyager 21 by HB, July 2019
 - changed example data and GSG steps
 
 This script shows all functions of the getting started guide that can be scripted.
 Variables are used often to make the script more understandable and also
 easily allow the user to change something.
 Writing own functions is avoided to make the script easily readable in sequential order.
 
 */

// changes: HasSliceTimeTable


var DicomPath = BrainVoyager.BrowseDirectory("Please select the directory with the DCM files");//"D:/Data Exercises/Dicoms/";
var SavingPath = BrainVoyager.BrowseDirectory("Please select the directory to save the data"); //"D:/Data Exercises/Script/";
var FilePath = SavingPath;

BrainVoyager.PrintToLog("Step 1: Creation of a functional project");
var DataFormat = "DICOM";
var FirstSourceFile = "JudEck_20181128_BI_Exercises_sess4-0002-0001-00001.dcm";
var NrVolumes  = 291;
var NrVolumesSkip = 0;
var CreateAMR = true;
var NrSlices = 64;
var STCname = "sub-01_ses-04_task-blocked_run- 1_bold"; 
var SwapBytes = false;
var MosaicResolutionX = 800;
var MosaicResolutionY = 800;
var NrBytes = 2;
var NrVolumesPerFile = 1;
var ResolutionX = 100;
var ResolutionY = 100;

var FMRname = "sub-01_ses-04_task-blocked_run- 1_bold";
var SavingName = SavingPath + "/" + ".fmr";
BrainVoyager.PrintToLog("DicomPath + FirstSourceFile: " + DicomPath + FirstSourceFile);
var FMR = BrainVoyager.CreateProjectMosaicFMR(DataFormat, DicomPath + "/" + FirstSourceFile, NrVolumes, NrVolumesSkip, CreateAMR, NrSlices,
 STCname, SwapBytes, MosaicResolutionX, MosaicResolutionY, NrBytes, SavingPath, NrVolumesPerFile, ResolutionX, ResolutionY);

FMR.SaveAs(SavingName);

//*************************************************************************
//Step 3: Creation of the stimulation protocol
//*************************************************************************
BrainVoyager.PrintToLog("Step 3: Creation of the stimulation protocol");

FMR.ClearStimulationProtocol();
FMR.StimulationProtocolExperimentName = "Faces Houses in LVF, CVF, RVF";
FMR.StimulationProtocolResolution = 1;
FMR.AddCondition("Faces_LVF");
FMR.AddCondition("Houses_RVF");
FMR.AddCondition("Faces_CVF");
FMR.AddCondition("Houses_LVF");
FMR.AddCondition("Faces_RVF");
FMR.AddCondition("Houses_CVF");

FMR.AddInterval("Faces_LVF", 4, 11);
FMR.AddInterval("Houses_RVF", 20, 27);
FMR.AddInterval("Faces_CVF", 36, 43);
FMR.AddInterval("Houses_LVF", 52, 59);
FMR.AddInterval("Faces_RVF", 68, 75);
FMR.AddInterval("Houses_CVF", 84, 91);
FMR.AddInterval("Faces_LVF", 100, 107);
FMR.AddInterval("Houses_RVF", 116, 123);
FMR.AddInterval("Faces_CVF", 132, 139);
FMR.AddInterval("Houses_LVF", 148, 155);
FMR.AddInterval("Faces_RVF", 164, 171);
FMR.AddInterval("Houses_CVF", 180, 187);
FMR.AddInterval("Faces_LVF", 196, 203);
FMR.AddInterval("Houses_RVF", 212, 219);
FMR.AddInterval("Faces_CVF", 228, 235);
FMR.AddInterval("Houses_LVF", 244, 251);
FMR.AddInterval("Faces_RVF", 260, 267);
FMR.AddInterval("Houses_CVF", 276, 283);

FMR.SetConditionColor("Faces_LVF", 200, 43, 43);
FMR.SetConditionColor("Houses_RVF", 200, 200, 43);
FMR.SetConditionColor("Faces_CVF", 43, 200, 43);
FMR.SetConditionColor("Houses_LVF", 43, 200, 200);
FMR.SetConditionColor("Faces_RVF", 43, 43, 200);
FMR.SetConditionColor("Houses_CVF", 200, 43, 200);

FMR.StimulationProtocolBackgroundColorR = 0;
FMR.StimulationProtocolBackgroundColorG = 0;
FMR.StimulationProtocolBackgroundColorB = 0;
FMR.StimulationProtocolTimeCourseColorR = 255;
FMR.StimulationProtocolTimeCourseColorG = 255;
FMR.StimulationProtocolTimeCourseColorB = 255;
FMR.StimulationProtocolTimeCourseThickness = 2;
FMR.SaveStimulationProtocol(SavingPath + "/s01_sess4_blocked_vol.prt");
FMR.Save(); // to save link to protocol permanently


//*************************************************************************
//Step 4: Statistical tests and time courses
//*************************************************************************
BrainVoyager.PrintToLog("Step 4: Statistical tests and time courses");


FMR.TR = 2000;
FMR.InterSliceTime = 80;
FMR.TimeResolutionVerified = true;
FMR.Save();

//Correlation calculation is not scriptable


//*************************************************************************
//Step 5: Preprocessing of FMR projects
//*************************************************************************
BrainVoyager.PrintToLog("Step 5: Preprocessing of FMR projects");

// <<<< Slice Scan Time Correction >>>>
var ScanOrder = 1; //0 = Ascending,  1 = Asc-Interleaved,  2 = Asc-Int2,   10 = Descending,  11 = Desc-Int,  12 = Desc-Int2
var InterpolationMethod = 1; //0 = trilinear, 1 = cubic spline, 2 = windowed SINC.
if (FMR.HasSliceTimeTable) {
 	FMR.CorrectSliceTimingUsingTimeTable(InterpolationMethod); 
} else {
	FMR.CorrectSliceTiming(ScanOrder, InterpolationMethod);
} 
var ResultFileName = FMR.FileNameOfPreprocessdFMR;
FMR.Close(); //FMR.Remove();
FMR = BrainVoyager.OpenDocument( ResultFileName );

// <<<< Motion correction >>>>
var TargetVolume = 1;
var InterpolationMethod = 2; //0 and 1 = trilinear, 2 = tri-linear detection and sinc apply, 3 = sinc.
var UseFullData = true;
var NrIterations = 100;
var CreateMovie = false;
var GenerateExtendedLogFile = false;
FMR.CorrectMotionEx(TargetVolume, InterpolationMethod, UseFullData, NrIterations, CreateMovie, GenerateExtendedLogFile);

var ResultFileName = FMR.FileNameOfPreprocessdFMR;
FMR.Remove(); //FMR.Close();
FMR = BrainVoyager.OpenDocument( ResultFileName );

// <<<< Temporal Filtering >>>>
var NrCycles = 2; 
FMR.TemporalHighPassFilterGLMFourier(NrCycles);

var ResultFileName = FMR.FileNameOfPreprocessdFMR;
FMR.Remove(); //FMR.Close();
FMR = BrainVoyager.OpenDocument( ResultFileName );


//*************************************************************************
//Step 6: Statistical analysis with the General Linear Model (GLM)
//*************************************************************************
BrainVoyager.PrintToLog("Step 6: Statistical analysis with the General Linear Model (GLM)");

FMR.ClearDesignMatrix();
FMR.AddPredictor("Faces_LVF");
FMR.SetPredictorValuesFromCondition("Faces_LVF", "Faces_LVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Faces_LVF");
FMR.AddPredictor("Houses_RVF");
FMR.SetPredictorValuesFromCondition("Houses_RVF", "Houses_RVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Houses_RVF");
FMR.AddPredictor("Faces_CVF");
FMR.SetPredictorValuesFromCondition("Faces_CVF", "Faces_CVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Faces_CVF");
FMR.AddPredictor("Houses_LVF");
FMR.SetPredictorValuesFromCondition("Houses_LVF", "Houses_LVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Houses_LVF");
FMR.AddPredictor("Faces_RVF");
FMR.SetPredictorValuesFromCondition("Faces_RVF", "Faces_RVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Faces_RVF");
FMR.AddPredictor("Houses_CVF");
FMR.SetPredictorValuesFromCondition("Houses_CVF", "Houses_CVF", 1.0);
FMR.ApplyHemodynamicResponseFunctionToPredictor("Houses_CVF");
FMR.SaveSingleStudyGLMDesignMatrix(SavingPath + "/FacesHousesDesignMatrix.sdm");

FMR.ComputeSingleStudyGLM();
FMR.ClearContrasts();
FMR.AddContrast("1 0 0 0 -1 0");
FMR.SetContrastValue("Faces_LVF", +1);
FMR.SetContrastValue("Faces_RVF", -1);
FMR.ShowGLM();
FMR.SaveGLM(SavingPath + "/FacesHouses_FMR.glm");
FMR.Close();

//*************************************************************************
//Step 7: Detailed GLM analysis of regions-of-interest (ROIs)
// Can be scripted via VMR-VTC VOIs
//*************************************************************************

//*************************************************************************
//Step 8: Event-related averaging
//*************************************************************************
//Not Scriptable


//*************************************************************************
//Step 9: Creation of a 3D anatomical project
//*************************************************************************

BrainVoyager.PrintToLog("Step 9: Creation of a 3D anatomical project");
var DicomPathAnatomical = BrainVoyager.BrowseDirectory("Please select the directory of the anatomical data");
var DataFormat = "DICOM";
var FirstSourceFile = "JudEck_20181128_BI_Exercises_sess4-0008-0001-00001.dcm";
var NrSlices = 192;
var IsLittleEndian = false; //specification of the byte order in the file, almost always false
var XSize = 256;
var YSize = 256;
var NrBytes = 2; //Number of bytes for each pixel, almost always 2
var VMRname = "sub-01_ses-04_acq-nondistorted_T1w";
var VMR = BrainVoyager.CreateProjectVMR( DataFormat, DicomPathAnatomical + "/" + FirstSourceFile, NrSlices, IsLittleEndian, XSize, YSize, NrBytes);
VMR.SaveAs( FilePath + "/" + VMRname + ".vmr");
VMR.CorrectIntensityInhomogeneities();
VMR.Close();


//*************************************************************************
//Step 10: Coregistration of functional and anatomical data
//*************************************************************************

VMRname = VMRname + "_IIHC";
var VMR = BrainVoyager.OpenDocument(FilePath + "/" + VMRname + ".vmr");
var FMRname = FMRname + "_SCCTBL_3DMCTS_LTR_THPGLMF2c";
var success =  VMR.CoregisterFMRToVMRUsingBBR(FilePath + "/" + FMRname + ".fmr");


//*************************************************************************
//Step 11: MNI Normalization of Anatomical Data
//*************************************************************************

VMR.NormalizeToMNISpace();
VMR.Close();

//*************************************************************************
//Step 12: Automatic 3D-3D alignment
//*************************************************************************
//Not Scriptable


//*************************************************************************
//Step 12: MNI transformation of functional data
//*************************************************************************

var MNIVMRfilename = FilePath  + "/"+ VMRname +  "_MNI.vmr";
var IAfilename = FilePath + "/" + FMRname + "-TO-" + VMRname + "_IA.trf";
var FAfilename = FilePath + "/"  + FMRname + "-TO-" + VMRname + "_BBR_FA.trf";
var MNIfilename = FilePath + "/"  + VMRname + "_TO_MNI_a12.trf";
var VTCfilename = FilePath + "/"  + FMRname + "_MNI.vtc";
var DataType = 2; // 1: int16, 2: float32
var Resolution = 3; // one of 1, 2 or 3 mm^2
var Interpolation = 1; //0 = nearest neighbor, 1 = trilinear, 2 = sinc;
var Threshold = 100; //Intensity treshold to avoid interpolation calculations in non-brain voxels
var UseExtendedBoundingBox = false;

VMR = BrainVoyager.OpenDocument(MNIVMRfilename);
VMR.ExtendedTALSpaceForVTCCreation = UseExtendedBoundingBox; 
VMR.CreateVTCInMNISpace(FilePath + "/" + FMRname + ".fmr", IAfilename, FAfilename, MNIfilename, VTCfilename, DataType, Resolution, Interpolation, Threshold);


//*************************************************************************
//Step 13: Statistical analysis of 3D functional data
//*************************************************************************

var VMR = BrainVoyager.ActiveDocument;
VMR.LinkVTC(VTCfilename);
VMR.LoadSingleStudyGLMDesignMatrix(SavingPath + "/FacesHousesDesignMatrix.sdm");
VMR.ComputeSingleStudyGLM();
VMR.SaveGLM(SavingPath + "/FacesHouses_VTC.glm");
VMR.ClearContrasts();
VMR.AddContrast("Faces > Houses");
VMR.SetContrastString("1 -1 1 -1 1 -1");
VMR.SetContrastValue("Faces_LVF", +1);
VMR.SetContrastValue("Faces_RVF", +1);
VMR.SetContrastValue("Faces_CVF", +1);
VMR.SetContrastValue("Houses_LVF", -1);
VMR.SetContrastValue("Houses_RVF", -1);
VMR.SetContrastValue("Houses_CVF", -1);
VMR.ShowGLM(); 

//*************************************************************************
//Step 14: Preprocessing of VTC Documents
//*************************************************************************

VMR.SpatialGaussianSmoothing(4, "mm");

//*************************************************************************
//Step 15: Event-related averaging of 3D functional data
//*************************************************************************
//Not Scriptable


