
/* 	
	GSG 	Part 2: Analysis in surface space - SRF-MTC projects
	Script for BrainVoyager 
	By Joost Mulders, 06-2013
    	Modified for BrainVoyager 20.4 by HB, 14-12-16
       	 - changed 'BrainVoyagerQX' to 'BrainVoyager'
       	 - changed hardcoding of path to use of BrowseDirectory()
       	 - added file separator to path and filename concatenation
         - removed references to the file CG2_3DT1FL_CLEAN.vmr (not used in GSG 2.13 any more)
         - added step 22
	Modified for BrainVoyager 21 by HB, July 2019
         - changed example data and GSG steps

	This script shows all functions of the getting started guide that can be scripted.
	Variables are used often to make the script more understandable and also
	easily allow the user to change something.
	Writing own functions is avoided to make the script easily readable in sequential order.

	Files Needed:
	- VMRs:	- sub-01_ses-04_acq-nondistorted_T1w_IIHC_MNI.vmr
	- SRFs: - sub-01_ses-04_acq-nondistorted_T1w_IIHC_MNI_WM_LH_RECOSM.srf
*/


var SavingPath = BrainVoyager.BrowseDirectory("Please select the directory to save the data");
var FilePath = SavingPath; //Path of all files mentioned above

var FMRname = "sub-01_ses-04_task-blocked_run- 1_bold_SCCTBL_3DMCTS_LTR_THPGLMF2c";
var VMRname = "sub-01_ses-04_acq-nondistorted_T1w_IIHC_MNI";


//Step 16: Surface reconstruction of the head
//Not Scriptable


//var VMR = BrainVoyager.ActiveDocument;
//VMR.LinkVTC(VTCfilename);


//*************************************************************************
//Step 17: Navigation in the surface module window
//*************************************************************************

var VMR = BrainVoyager.OpenDocument(FilePath + "/" + VMRname + ".vmr");
if (VMR == undefined) return;
var meshscene = VMR.CreateMeshScene();
var SRFname = BrainVoyager.BrowseFile("Please select the surface file", "*.srf");
var success = meshscene.LoadMesh(SRFname);
var mesh = meshscene.CurrentMesh;
//mesh.ViewPointTranslationX 
VMR.ViewpointTranslationX = -500;
VMR.ViewpointTranslationY = 0;
VMR.ViewpointTranslationZ = 0;
VMR.ViewpointRotationX = 0;
VMR.ViewpointRotationY = 180;
VMR.ViewpointRotationZ = 180;
mesh.UpdateAppearance();

//Step 18: Slicing a polygon mesh
//Not Scriptable

//Step 19: Automatic cortex segmentation
//Not Scriptable

//*************************************************************************
//Step 20: Cortex inflation
//*************************************************************************

var NrOfIterations = 500;
var SmoothingForce = 0.8;
mesh.MorphingUpdateInterval = 10;
mesh.InflateMesh(NrOfIterations, SmoothingForce, ""); // if "" used for 3rd param (area reference mesh), the current mesh at the moment the fn is called is used to calculate ref mesh area
var NrOfIterations = 300;
mesh.InflateMesh(NrOfIterations, SmoothingForce, "");
mesh.SaveAs(FilePath + "/" + "sub-01_ses- 04_acq-nondistorted_T1w_IIHC_MNI_WM_LH_RECOSM_INFL.srf");


//Step 21: Changing mesh colors
//Not Scriptable

//*************************************************************************
//Step 22: Statistical maps on cortex meshes
// We run statistics via a GLM on the mesh time course (*.mtc) 
// instead of creating a surface map (*.smp) from the volume map (*.vmp) in the Getting Started Guide
//*************************************************************************

var VTCfilename = FilePath + "/" + FMRname + "_MNI.vtc";
VMR.LinkVTC(VTCfilename);
if (mesh == undefined) return;
var ok = mesh.CreateMTCFromVTC(-1.0, 2.0, SavingPath + "/FacesHouses_MNI_LH.mtc" );
if (!ok) {
    BrainVoyager.PrintToLog("Could not create MTC data from VTC data.");
} else {
    ok = mesh.LinkMTC(SavingPath + "/FacesHouses_MNI_LH.mtc" );
    if (!ok) return;
    mesh.ClearDesignMatrix();
    ok = mesh.LoadSingleStudyGLMDesignMatrix(SavingPath + "/FacesHousesDesignMatrix.sdm");
    if (!ok) return;
    mesh.CorrectForSerialCorrelations = 2; // 1 -> AR(1), 2 -> AR(2)
    mesh.ComputeSingleStudyGLM();
    mesh.ShowGLM();
    mesh.SaveGLM(SavingPath + "/FacesHouses_MNI_LH.glm");
}

// alternatively: use mesh.CreateSurfaceMapFromVolumeMap(interpolation, nonZeroValues);
// with the following parameters - Parameter 1: Interpolation method (integer), Parameter 2: Sample only non zero values (boolean) for example
// mesh.CreateSurfaceMapFromVolumeMap(1, 0);

